clear all; clc;

%Define directories for input 
rootdir = pwd;
sourcedir = fullfile(rootdir, 'sourcedata');
BIDSdir = fullfile(rootdir,'BIDS');
derivdir = fullfile(rootdir,'derivatives','fmriprep');
outputdir = fullfile(rootdir,'firstlevel','model_1_basic');
matlabpath = path;
codedir = fullfile(rootdir,'code');

sourcelist = dir(fullfile(sourcedir,'sub-*'));
sourcesubjs = cellstr(char(sourcelist(:).name));

% define directory to spm
if ~exist('spm.m', 'file')
    spmpathcommand = "addpath('your_spm_rootdir','-end')";
    error('\nspm12 not found on Matlab path, please add WITHOUT subfolders using the Matlab GUI')
else
    spm_dir = which('spm.m');
    spm_dir = strsplit(spm_dir,'/spm.m');
    spm_dir = spm_dir{1,1};
end 

if sum(contains(matlabpath,codedir)) == 0
    addpath(genpath(codedir),'-end');
    warning('\nadding %s to end of Matlab path',codedir)
end 

% setting input files and analysis parameters
brainmask='/data/proj_emosex/firstlevel/masks/rmask_ICV.nii'; 

%directories to smoothed data we want to analyze

derivlist = dir(fullfile(derivdir,'sub-*','func','*preproc_bold.nii.gz*'));
eventslist = dir(fullfile(BIDSdir,'sub-*','func','*events.tsv'));
derivlist = derivlist([derivlist(:).isdir]);
derivsubjs = cellstr(char(derivlist.name));
zipfilename = cell(size(derivsubjs,1),1);
eventssubjs = cell(size(derivsubjs,1),1);

for derivsub = 1:size(derivsubjs,1)
    zipfilename{derivsub,1} = fullfile(derivlist(derivsub).folder,derivlist(derivsub).name);
end

for event = 1:size(derivsubjs,1)
    eventssubjs{event,1} = fullfile(eventslist(event).folder,eventslist(event).name);
end


TR=2.5; % TR in seconds
nsubj = size(zipfilename,1);

% unzipping files

for k=1:nsubj
    file_nii=(zipfilename{k}(1:end-3));
    if not(isfile(file_nii))
        disp(['unzipping file ' zipfilename{k}])
        gunzip(zipfilename{k});
    end
    filename{k}=file_nii;
end


for k=1:nsubj
    
    eventsfile = eventssubjs{k};
    disp(['loading events in file ' eventsfile]);
    
    T=readtable(eventsfile,'filetype','delimitedtext');
    
    ncond=size(T.trial_type,1);
    
    % onsets and durations (with time expressed in seconds)
    
    for j=1:ncond
        
        x=T.trial_type(j);
        
        cond_name{j}=['c' num2str(j) '_' x{1}]; %f.e. output c1_neutral, c2_negative, c3_neutral, c4_positive, c5_neutral, c6_sex
        
        onset{j}=T.onset(j);
        
        duration{j}=T.duration(j);
        
    end
    
    subj_parameters(k).cond_name=cond_name;
    subj_parameters(k).onset=onset;
    subj_parameters(k).duration=duration;
    
end



% start the processing

addpath(spm_dir);

Vm=spm_vol(brainmask);

mask=spm_read_vols(Vm);

[xdim,ydim,zdim]=size(mask);

ncomps=(nsubj-1)*nsubj/2;

isc_results=zeros(xdim,ydim,zdim,ncond,ncomps);

V=spm_vol(filename{1});
tdim=length(V);


for k=1:zdim
    
    
    disp(['processing ISC for slice ' num2str(k) ' / ' num2str(zdim)]);
    
    maskind=find(mask(:,:,k)>0.5);
    
    nv=length(maskind);
    
    if nv>0
        
        buffer=zeros(nv,tdim,nsubj);
        
        %disp('data buffering');
        
        for i=1:nsubj
            
            V=spm_vol(filename{i});
            
            %tic;
            dataz=zeros(V(1).dim(1),V(1).dim(2),length(V));
            
            for t=1:length(V)
                dataz(:,:,t) = spm_slice_vol(V(t),1\spm_matrix([0 0 k]),V(t).dim(1:2),1);
            end
            %toc;
            
            %             tic;
            %             data=spm_read_vols(V);
            %
            %             dataz=data(:,:,k,:);
            %             toc;
            
            dataz=reshape(dataz,xdim*ydim,tdim);
            
            buffer(:,:,i)=dataz(maskind,:);
            
        end
        
        
        for j=1:ncond
            
            %disp(['processing condition ' cond_name{j}]);
            
            ntp=Inf;
            
            for i=1:nsubj
                
                onset=subj_parameters(i).onset{j};
                
                duration=subj_parameters(i).duration{j};
                
                
                time_tot=[];
                
                for qq=1:length(onset)
                    
                    start_t=ceil(onset(qq)/TR);
                    
                    end_t=min(tdim,fix((onset(qq)+duration(qq))/TR));
                    
                    time_vect=start_t:end_t;
                    
                    time_tot=[time_tot time_vect];
                    
                end
                
                ntpx=length(time_tot);
                
                ntp=min(ntp,ntpx);
                
            end
            
            buffer_cond=zeros(nv,ntp,nsubj);
            
            for i=1:nsubj
                
                sig=[];
                
                for qq=1:length(onset)
                    
                    start_t=ceil(onset(qq)/TR);
                    
                    end_t=min(tdim,fix((onset(qq)+duration(qq))/TR));
                    
                    time_vect=start_t:end_t;
                    
                    tmp_sig=squeeze(buffer(:,time_vect,i));
                    
                    tmp_sig=zscore(tmp_sig,0,2);
                    
                    sig=[sig tmp_sig];
                    
                end
                
                buffer_cond(:,:,i)=sig(:,1:ntp);
                
            end
            
            
            cont=0;
            
            for i=1:nsubj
                
                sig1=buffer_cond(:,:,i);
                
                for q=i+1:nsubj
                    
                    sig2=buffer_cond(:,:,q);
                    
                    cont=cont+1;
                    
                    if sum(abs(sig1(:)))>0 && sum(abs(sig2(:)))>0
                        
                        
                        X=corr(sig1',sig2');
                        
                        ima=zeros(xdim,ydim);
                        
                        ima(maskind)=diag(X);
                        
                        isc_results(:,:,k,j,cont)=atanh(ima);  % r-to-z conversion (Fisher trasnform)
                        
                    end
                    
                end
                
            end
            
        end
        
    end
    
    
end



% saving results

disp('saving output images');

Vt=V(1);

Vt.dt=[16 0];
Vt.pinfo=[0.00001; 0; 0];

for j=1:ncond
    subjOUTdir = fullfile(outputdir,cond_name{j});
    if ~exist(subjOUTdir,'dir')
            mkdir(subjOUTdir);
    end
    cont=0;
    
    for i=1:nsubj
        
        for k=i+1:nsubj
            
            cont=cont+1;
            
            s1=['0' num2str(i)];
            s1=s1(end-1:end);
            s2=['0' num2str(k)];
            s2=s2(end-1:end);
            
            Vt.fname=[subjOUTdir filesep 'isc_s' s1 '_vs_s' s2 '_' cond_name{j} '.nii'];
            
            spm_write_vol(Vt,squeeze(isc_results(:,:,:,j,cont)));
            
        end
        
    end
    
end


% deleting temporary files

for k=1:nsubj
    delete(filename{k});
end



