clear all; clc;
warning off;

% setting paths
rootdir = pwd;
matlabpath = path;
codedir = fullfile(rootdir,'code');

% define directory to spm
if ~exist('spm.m', 'file')
    spmpathcommand = "addpath('your_spm_rootdir','-end')";
    error('\nspm12 not found on Matlab path, please add WITHOUT subfolders using the Matlab GUI')
else
    spm_dir = which('spm.m');
    spm_dir = strsplit(spm_dir,'/spm.m');
    spm_dir = spm_dir{1,1};
end 

if sum(contains(matlabpath,codedir)) == 0
    addpath(genpath(codedir),'-end');
    warning('\nadding %s to end of Matlab path',codedir)
end 

%setting input files and output directory
input_dir='/data/proj_emosex/firstlevel/model_1_basic';


output_dir='/data/proj_emosex/secondlevel';


addpath(spm_dir);


%% 1) Reorganize and rename files

nsubj=34;


condition(1).name='neutral';
condition(1).folder{1}='c1_neutral';
condition(1).folder{2}='c3_neutral';
condition(1).folder{3}='c5_neutral';
condition(2).name='sex';
condition(2).folder{1}='c4_sex';
condition(3).name='positive';
condition(3).folder{1}='c6_positive';
condition(4).name='negative';
condition(4).folder{1}='c2_negative';


for w=1:length(condition)
    for i=1:nsubj
        for j=i+1:nsubj
            str1=['0' num2str(i)];
            str1=str1(end-1:end);
            str2=['0' num2str(j)];
            str2=str2(end-1:end);
            for k=1:length(condition(w).folder)
                filename=['isc_s' str1 '_vs_s' str2 '_' condition(w).folder{k} '.nii'];
                V=spm_vol([input_dir filesep condition(w).folder{k} filesep filename]);
                disp(V.fname);
                data=spm_read_vols(V);
                if k==1
                    datatot=data;
                else
                    datatot=datatot+data;
                end
            end
            datatot=datatot/length(condition(w).folder);
            V.fname=[output_dir filesep 'input_data' filesep condition(w).name filesep 'isc_s' str1 '_vs_s' str2 '.nii'];
            if not(isfolder([output_dir filesep 'input_data' filesep condition(w).name]))
                mkdir([output_dir filesep 'input_data' filesep condition(w).name]);
            end
            spm_write_vol(V,datatot);
        end
    end
end

% average the isc for true couples vs. non-couples

ncouples=nsubj/2;

for w=1:length(condition)
    for k=1:ncouples
        % select couple indices
        i=2*k-1;
        j=2*k;
            str1=['0' num2str(i)];
            str1=str1(end-1:end);
            str2=['0' num2str(j)];
            str2=str2(end-1:end);
            str3=['0' num2str(k)];
            str3=str3(end-1:end);
            couple_inputfile=[output_dir filesep 'input_data' filesep condition(w).name filesep 'isc_s' str1 '_vs_s' str2 '.nii'];
            couple_outputfile=[output_dir filesep 'input_data' filesep condition(w).name filesep 'isc_tc' str3 '.nii'];
            copyfile(couple_inputfile,couple_outputfile);
        % select non-couple indices
        list_nc=[1:i-1 j+1:nsubj];
        for p=1:length(list_nc)
            str4=['0' num2str(list_nc(p))];
            str4=str4(end-1:end);
            if list_nc(p) > i
                noncouple_inputfile=[output_dir filesep 'input_data' filesep condition(w).name filesep 'isc_s' str1 '_vs_s' str4 '.nii'];
            else
                noncouple_inputfile=[output_dir filesep 'input_data' filesep condition(w).name filesep 'isc_s' str4 '_vs_s' str1 '.nii'];

            end
            V=spm_vol(noncouple_inputfile);
            disp(V.fname);
            data=spm_read_vols(V);
            if p==1
                datatot=data;
            else
                datatot=datatot+data;
            end
            if list_nc(p) > j
                noncouple_inputfile=[output_dir filesep 'input_data' filesep condition(w).name filesep 'isc_s' str2 '_vs_s' str4 '.nii'];
            else
                noncouple_inputfile=[output_dir filesep 'input_data' filesep condition(w).name filesep 'isc_s' str4 '_vs_s' str2 '.nii'];
            end
            V=spm_vol(noncouple_inputfile);
            disp(V.fname);
            data=spm_read_vols(V);
            datatot=datatot+data;
        end
        datatot=datatot/(2*(nsubj-2));
        noncouple_outputfile=[output_dir filesep 'input_data' filesep condition(w).name filesep 'isc_nc' str3 '.nii'];
        V.fname=noncouple_outputfile;
        %Vt.fname=[subjOUTdir filesep 'isc_s' s1 '_vs_s' s2 '_' cond_name{j} '.nii'];
        spm_write_vol(V,datatot);
    end
end


%% 2) Statistical analyses for couples and non-couples

%% 2.1.1) Two-way ANOVA across conditions and relationships (partner vs. non-partner)

output_dir5=[output_dir filesep 'results_partner_vs_non-partner'];
if not(isfolder(output_dir5))
    mkdir(output_dir5);
end

ncouples=17;
nperm=2000; % number of permutations

condition(1).name='neutral';
condition(1).folder{1}='c1_neutral'; %average the iscs from the neutral conditions
condition(1).folder{2}='c3_neutral';
condition(1).folder{3}='c5_neutral';
condition(2).name='sex';
condition(2).folder{1}='c4_sex';
condition(3).name='positive';
condition(3).folder{1}='c6_positive';
condition(4).name='negative';
condition(4).folder{1}='c2_negative';

folder_structure{1}='reference'; %first cell is the reference
for l=1:nperm
    str=['000' num2str(l)];
    str=str(end-3:end);
    folder_structure{l+1}=['permutation_' str]; %all other cells are the permutations numbered in consequtive order
end


output_dir6x=[output_dir5 filesep 'two-way_anova_2000_perm'];
if not(isfolder(output_dir6x))
    mkdir(output_dir6x);
end


for l=1:length(folder_structure)
    
    disp(folder_structure{l});
    output_dir6=[output_dir6x filesep folder_structure{l}];
    if not(isfolder(output_dir6))
        mkdir(output_dir6); %
    end
    
    if isfile([output_dir6 filesep 'SPM.mat'])
        delete([output_dir6 filesep 'SPM.mat']);
    end
    
    clear matlabbatch
    matlabbatch{1}.spm.stats.factorial_design.dir = {output_dir6};
    matlabbatch{1}.spm.stats.factorial_design.des.fblock.fac(1).name = 'Relationship';
    matlabbatch{1}.spm.stats.factorial_design.des.fblock.fac(1).dept = 0;
    matlabbatch{1}.spm.stats.factorial_design.des.fblock.fac(1).variance = 1;
    matlabbatch{1}.spm.stats.factorial_design.des.fblock.fac(1).gmsca = 0;
    matlabbatch{1}.spm.stats.factorial_design.des.fblock.fac(1).ancova = 0;
    matlabbatch{1}.spm.stats.factorial_design.des.fblock.fac(2).name = 'Condition';
    matlabbatch{1}.spm.stats.factorial_design.des.fblock.fac(2).dept = 0;
    matlabbatch{1}.spm.stats.factorial_design.des.fblock.fac(2).variance = 1;
    matlabbatch{1}.spm.stats.factorial_design.des.fblock.fac(2).gmsca = 0;
    matlabbatch{1}.spm.stats.factorial_design.des.fblock.fac(2).ancova = 0;
    matlabbatch{1}.spm.stats.factorial_design.des.fblock.fac(3).name = 'Subject';
    matlabbatch{1}.spm.stats.factorial_design.des.fblock.fac(3).dept = 0;
    matlabbatch{1}.spm.stats.factorial_design.des.fblock.fac(3).variance = 0;
    matlabbatch{1}.spm.stats.factorial_design.des.fblock.fac(3).gmsca = 0;
    matlabbatch{1}.spm.stats.factorial_design.des.fblock.fac(3).ancova = 0;
    for k=1:ncouples %for every couple the input data is structured as neutral tc, neutral nc, sex tc, sex nc, positive tc, positive nc, negative tc, negative nc
        str3=['0' num2str(k)];
        str3=str3(end-1:end);
        clear input_data
        for w=1:length(condition)
            input_data{(w-1)*2+1,:}=[output_dir filesep 'input_data' filesep condition(w).name filesep 'isc_tc' str3 '.nii'];
            input_data{2*w,:}=[output_dir filesep 'input_data' filesep condition(w).name filesep 'isc_nc' str3 '.nii'];
        end
        
        % add randomization
        
        nelem=size(input_data,1);
        if l==1
            perm_order=[1:nelem];
        else
            perm_order=randperm(nelem);
        end
        
        
        matlabbatch{1}.spm.stats.factorial_design.des.fblock.fsuball.fsubject(k).scans = input_data(perm_order);
        matlabbatch{1}.spm.stats.factorial_design.des.fblock.fsuball.fsubject(k).conds = [1,1;2,1;1,2;2,2;1,3;2,3;1,4;2,4];
    end
    matlabbatch{1}.spm.stats.factorial_design.des.fblock.maininters{1}.fmain.fnum = 1;
    matlabbatch{1}.spm.stats.factorial_design.des.fblock.maininters{2}.fmain.fnum = 2;
    matlabbatch{1}.spm.stats.factorial_design.des.fblock.maininters{3}.inter.fnums = [1
        2];
    matlabbatch{1}.spm.stats.factorial_design.cov = struct('c', {}, 'cname', {}, 'iCFI', {}, 'iCC', {});
    matlabbatch{1}.spm.stats.factorial_design.multi_cov = struct('files', {}, 'iCFI', {}, 'iCC', {});
    matlabbatch{1}.spm.stats.factorial_design.masking.tm.tm_none = 1;
    matlabbatch{1}.spm.stats.factorial_design.masking.im = 1;
    matlabbatch{1}.spm.stats.factorial_design.masking.em = {''};
    matlabbatch{1}.spm.stats.factorial_design.globalc.g_omit = 1;
    matlabbatch{1}.spm.stats.factorial_design.globalm.gmsca.gmsca_no = 1;
    matlabbatch{1}.spm.stats.factorial_design.globalm.glonorm = 1;
    spm_jobman('run', matlabbatch);
    clear matlabbatch
    matlabbatch{1}.spm.stats.fmri_est.spmmat = {[output_dir6 filesep 'SPM.mat']};
    matlabbatch{1}.spm.stats.fmri_est.write_residuals = 0;
    matlabbatch{1}.spm.stats.fmri_est.method.Classical = 1;
    spm_jobman('run', matlabbatch);
    clear matlabbatch
    matlabbatch{1}.spm.stats.con.spmmat = {[output_dir6 filesep 'SPM.mat']};
    matlabbatch{1}.spm.stats.con.consess{1}.fcon.name = 'ISC_effect_relationship';
    matlabbatch{1}.spm.stats.con.consess{1}.fcon.weights = [1 -1 0 0 0 0 ones(1,4)/4 -ones(1,4)/4];
    matlabbatch{1}.spm.stats.con.consess{1}.fcon.sessrep = 'none';
    matlabbatch{1}.spm.stats.con.consess{2}.fcon.name = 'ISC_effect_condition';
    matlabbatch{1}.spm.stats.con.consess{2}.fcon.weights = [0 0 -0.75 -0.25 0.25 0.75 -0.75/2 -0.25/2 0.25/2 0.75/2 -0.75/2 -0.25/2 0.25/2 0.75/2];
    matlabbatch{1}.spm.stats.con.consess{2}.fcon.sessrep = 'none';
    matlabbatch{1}.spm.stats.con.consess{3}.fcon.name = 'ISC_interaction_relationship_by_condition';
    matlabbatch{1}.spm.stats.con.consess{3}.fcon.weights = [0 0 0 0 0 0 -0.75 -0.25 0.25 0.75 0.75 0.25 -0.25 -0.75];
    matlabbatch{1}.spm.stats.con.consess{3}.fcon.sessrep = 'none';
    matlabbatch{1}.spm.stats.con.delete = 1;
    spm_jobman('run', matlabbatch);
    
end


contrast{1}='main_effect_relationship';
contrast{2}='main_effect_condition';
contrast{3}='interaction_relationship_condition';

 %% 2.1.2) Two sample t-test two-way ANOVA
 
output_dir5=[output_dir filesep 'results_partner_vs_non-partner'];
if not(isfolder(output_dir5))
    mkdir(output_dir5);
end

ncouples=17;
nperm=2000; % number of permutations

condition(1).name='neutral';
condition(1).folder{1}='c1_neutral';
condition(1).folder{2}='c3_neutral';
condition(1).folder{3}='c5_neutral';
condition(2).name='sex';
condition(2).folder{1}='c4_sex';
condition(3).name='positive';
condition(3).folder{1}='c6_positive';
condition(4).name='negative';
condition(4).folder{1}='c2_negative';

folder_structure{1}='reference'; %first cell is the reference
for l=1:nperm
    str=['000' num2str(l)];
    str=str(end-3:end);
    folder_structure{l+1}=['permutation_' str]; %all other cells are the permutations numbered in consequtive order
end


output_dir6x=[output_dir5 filesep 'two-way_anova_2000_perm'];
if not(isfolder(output_dir6x))
    mkdir(output_dir6x);
end

 
contrast{1}='main_effect_relationship';
contrast{2}='main_effect_condition';
contrast{3}='interaction_relationship_condition';

for k=1:length(contrast)
    
    output_dir6=[output_dir6x filesep contrast{k}]; %e.g. secondlevel/results_partner_vs_non-partner/two-way_anova/main_effect_condition
    if not(isfolder(output_dir6))
        mkdir(output_dir6);
    end
    
    str=['000' num2str(k)];

    filename=['spmF_' str '.nii'];
    
    clear files_snpm
    for l=1:length(folder_structure)
        files_snpm{l,:}=[output_dir6x filesep folder_structure{l} filesep filename];
    end
    
    
    clear matlabbatch
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.DesignName = '2 Groups: Two Sample T test; 1 scan per subject';
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.DesignFile = 'snpm_bch_ui_TwoSampT';
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.dir = {output_dir6}; 
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.scans1 = files_snpm(1,:);
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.scans2 = files_snpm(2:end,:);
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.cov = struct('c', {}, 'cname', {});
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.nPerm = 5000;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.vFWHM = [10 10 10];
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.bVolm = 1;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.ST.ST_none = 0;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.masking.tm.tm_none = 1;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.masking.im = 1;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.masking.em = {''};
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.globalc.g_omit = 1;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.globalm.gmsca.gmsca_no = 1;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.globalm.glonorm = 1;
    matlabbatch{2}.spm.tools.snpm.cp.snpmcfg = {[output_dir6 filesep 'SnPMcfg.mat']};
    matlabbatch{3}.spm.tools.snpm.inference.SnPMmat = {[output_dir6 filesep 'SnPMcfg.mat']};
    matlabbatch{3}.spm.tools.snpm.inference.Thr.Vox.VoxSig.FWEth = 0.05;
    matlabbatch{3}.spm.tools.snpm.inference.Tsign = 1;
    matlabbatch{3}.spm.tools.snpm.inference.WriteFiltImg.WF_no = 0;
    matlabbatch{3}.spm.tools.snpm.inference.Report = 'MIPtable';
    spm_jobman('run', matlabbatch);
    
end

% cleaning tempporary files
for l=1:length(folder_structure)
    output_dir6=[output_dir6x filesep folder_structure{l}];
    rmdir(output_dir6,'s');
end
    
%% 2.2.1) Paired t-test within condition (between couples vs non-couples)

output_dir5=[output_dir filesep 'results_partner_vs_non-partner'];
if not(isfolder(output_dir5))
    mkdir(output_dir5);
end

ncouples=17;
nperm=2000; % number of permutations

condition(1).name='neutral';
condition(1).folder{1}='c1_neutral';
condition(1).folder{2}='c3_neutral';
condition(1).folder{3}='c5_neutral';
condition(2).name='sex';
condition(2).folder{1}='c4_sex';
condition(3).name='positive';
condition(3).folder{1}='c6_positive';
condition(4).name='negative';
condition(4).folder{1}='c2_negative';

folder_structure{1}='reference'; %first cell is the reference
for l=1:nperm
    str=['000' num2str(l)];
    str=str(end-3:end);
    folder_structure{l+1}=['permutation_' str]; %all other cells are the permutations numbered in consequtive order
end


for cond=1:length(condition)
    clear matlabbatch
    output_dir6x=[output_dir5 filesep 'paired_t-test_2000_perm_' condition(cond).name];
    if not(isfolder(output_dir6x))
        mkdir(output_dir6x);
    end
    for l=1:length(folder_structure)
        
        disp(folder_structure{l});
        output_dir6=[output_dir6x filesep folder_structure{l}];
        if not(isfolder(output_dir6))
            mkdir(output_dir6); %
        end
        
        if isfile([output_dir6 filesep 'SPM.mat'])
            delete([output_dir6 filesep 'SPM.mat']);
        end
        
        clear matlabbatch
        for k=1:ncouples %for every couple the input data is structured as neutral tc, neutral nc, sex tc, sex nc, positive tc, positive nc, negative tc, negative nc
            str3=['0' num2str(k)];
            str3=str3(end-1:end);
            clear input_data
            for w=1:length(condition)
                input_data{(w-1)*2+1,:}=[output_dir filesep 'input_data' filesep condition(w).name filesep 'isc_tc' str3 '.nii'];
                input_data{2*w,:}=[output_dir filesep 'input_data' filesep condition(w).name filesep 'isc_nc' str3 '.nii'];
            end
            
            % add randomization
            
            nelem=size(input_data,1);
            if l==1
                perm_order=[1:nelem];
            else
                perm_order=randperm(nelem);
            end
            
            input_data=input_data(perm_order);
            
            matlabbatch{1}.spm.stats.factorial_design.des.pt.pair(k).scans = {
                input_data{(cond-1)*2+1,:}
                input_data{2*cond,:}
                }; %give as first input the ISC of tc for the specific condition you are looking at, as the second input the nc
        end
        matlabbatch{1}.spm.stats.factorial_design.dir = {output_dir6};
        matlabbatch{1}.spm.stats.factorial_design.des.pt.gmsca = 0;
        matlabbatch{1}.spm.stats.factorial_design.des.pt.ancova = 0;
        matlabbatch{1}.spm.stats.factorial_design.cov = struct('c', {}, 'cname', {}, 'iCFI', {}, 'iCC', {});
        matlabbatch{1}.spm.stats.factorial_design.multi_cov = struct('files', {}, 'iCFI', {}, 'iCC', {});
        matlabbatch{1}.spm.stats.factorial_design.masking.tm.tm_none = 1;
        matlabbatch{1}.spm.stats.factorial_design.masking.im = 1;
        matlabbatch{1}.spm.stats.factorial_design.masking.em = {''};
        matlabbatch{1}.spm.stats.factorial_design.globalc.g_omit = 1;
        matlabbatch{1}.spm.stats.factorial_design.globalm.gmsca.gmsca_no = 1;
        matlabbatch{1}.spm.stats.factorial_design.globalm.glonorm = 1;
        spm_jobman('run', matlabbatch);
        clear matlabbatch
        matlabbatch{1}.spm.stats.fmri_est.spmmat = {[output_dir6 filesep 'SPM.mat']};
        matlabbatch{1}.spm.stats.fmri_est.write_residuals = 0;
        matlabbatch{1}.spm.stats.fmri_est.method.Classical = 1;
        spm_jobman('run', matlabbatch);
        clear matlabbatch
        matlabbatch{1}.spm.stats.con.spmmat = {[output_dir6 filesep 'SPM.mat']};
        matlabbatch{1}.spm.stats.con.consess{1}.tcon.name = 'couple vs non couple';
        matlabbatch{1}.spm.stats.con.consess{1}.tcon.weights = [1 -1];
        matlabbatch{1}.spm.stats.con.consess{1}.tcon.sessrep = 'none';
        matlabbatch{1}.spm.stats.con.delete = 0;
        spm_jobman('run', matlabbatch);
    end
    
end

%% 2.2.2) Two sample t-test for paired t-test within condition

contrast{1}='effect_relationship_within_neutral';
contrast{2}='effect_relationship_within_sex';
contrast{3}='effect_relationship_within_positive';
contrast{4}='effect_relationship_within_negative';

output_dir5=[output_dir filesep 'results_partner_vs_non-partner'];
if not(isfolder(output_dir5))
    mkdir(output_dir5);
end

ncouples=17;
nperm=2000; % number of permutations

condition(1).name='neutral';
condition(1).folder{1}='c1_neutral';
condition(1).folder{2}='c3_neutral';
condition(1).folder{3}='c5_neutral';
condition(2).name='sex';
condition(2).folder{1}='c4_sex';
condition(3).name='positive';
condition(3).folder{1}='c6_positive';
condition(4).name='negative';
condition(4).folder{1}='c2_negative';

folder_structure{1}='reference'; %first cell is the reference
for l=1:nperm
    str=['000' num2str(l)];
    str=str(end-3:end);
    folder_structure{l+1}=['permutation_' str]; %all other cells are the permutations numbered in consequtive order
end

for k=1:length(condition)
    output_dir6x=[output_dir5 filesep 'paired_t-test_5000_perm_' condition(k).name];
    output_dir6=[output_dir6x filesep contrast{k}];
    if not(isfolder(output_dir6))
        mkdir(output_dir6);
    end
    
    filename=['spmT_0001.nii'];
      
    clear files_snpm
    for l=1:length(folder_structure)
        files_snpm{l,:}=[output_dir6x filesep folder_structure{l} filesep filename];
    end
    
    
    clear matlabbatch
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.DesignName = '2 Groups: Two Sample T test; 1 scan per subject';
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.DesignFile = 'snpm_bch_ui_TwoSampT';
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.dir = {output_dir6}; 
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.scans1 = files_snpm(1,:);
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.scans2 = files_snpm(2:end,:);
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.cov = struct('c', {}, 'cname', {});
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.nPerm = 5000;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.vFWHM = [10 10 10];
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.bVolm = 1;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.ST.ST_none = 0;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.masking.tm.tm_none = 1;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.masking.im = 1;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.masking.em = {''};
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.globalc.g_omit = 1;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.globalm.gmsca.gmsca_no = 1;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.globalm.glonorm = 1;
    matlabbatch{2}.spm.tools.snpm.cp.snpmcfg = {[output_dir6 filesep 'SnPMcfg.mat']};
    matlabbatch{3}.spm.tools.snpm.inference.SnPMmat = {[output_dir6 filesep 'SnPMcfg.mat']};
    matlabbatch{3}.spm.tools.snpm.inference.Thr.Vox.VoxSig.FWEth = 0.05;
    matlabbatch{3}.spm.tools.snpm.inference.Tsign = 1;
    matlabbatch{3}.spm.tools.snpm.inference.WriteFiltImg.WF_no = 0;
    matlabbatch{3}.spm.tools.snpm.inference.Report = 'MIPtable';
    spm_jobman('run', matlabbatch);
    
end


%% Statistical analyses for all pairs

%% 3.1.1) Paired t-test between conditions

output_dir5=[output_dir filesep 'results_allpairs'];
if not(isfolder(output_dir5))
    mkdir(output_dir5);
end

nsubj=34;
ncouples=17;
nperm = 2000;


condition(1).name='neutral';
condition(1).folder{1}='c1_neutral';
condition(1).folder{2}='c3_neutral';
condition(1).folder{3}='c5_neutral';
condition(2).name='sex';
condition(2).folder{1}='c4_sex';
condition(3).name='positive';
condition(3).folder{1}='c6_positive';
condition(4).name='negative';
condition(4).folder{1}='c2_negative';

folder_structure{1}='reference'; %first cell is the reference
for l=1:nperm
    %str=['000' num2str(l+933)];
    str=['000' num2str(l)];
    %str=['0933'];
    str=str(end-3:end);
    folder_structure{l+1}=['permutation_' str]; %all other cells are the permutations numbered in consequtive order
end


for cond=3:length(condition)
    clear matlabbatch
    output_dir6x=[output_dir5 filesep 'paired_t-test_2000_perm_sex_vs' condition(cond).name];
    if not(isfolder(output_dir6x))
        mkdir(output_dir6x);
    end
    for l=1:length(folder_structure)

        disp(folder_structure{l});
        output_dir6=[output_dir6x filesep folder_structure{l}];
        if not(isfolder(output_dir6))
            mkdir(output_dir6); %
        end

        if isfile([output_dir6 filesep 'SPM.mat'])
            delete([output_dir6 filesep 'SPM.mat']);
        end

        clear matlabbatch
        cont = 0;
        k=1;
        for i=1:nsubj
            for j=i+1:nsubj
                cont=cont+1;
                str1=['0' num2str(i)];
                str1=str1(end-1:end);
                str2=['0' num2str(j)];
                str2=str2(end-1:end);
                clear input_data
                for w=1:length(condition)
                    input_data{w,:}= [output_dir filesep 'input_data' filesep condition(w).name filesep 'isc_s' str1 '_vs_s' str2 '.nii'];
                end

                % add randomization

                nelem=size(input_data,1);
                if l==1
                    perm_order=[1:nelem];
                else
                    perm_order=randperm(nelem);
                end

                input_data=input_data(perm_order);

                matlabbatch{1}.spm.stats.factorial_design.des.pt.pair(k).scans = {
                    input_data{2,:}
                    input_data{cond,:}
                    }; 
                k=k+1;
            end
        end
        matlabbatch{1}.spm.stats.factorial_design.dir = {output_dir6};
        matlabbatch{1}.spm.stats.factorial_design.des.pt.gmsca = 0;
        matlabbatch{1}.spm.stats.factorial_design.des.pt.ancova = 0;
        matlabbatch{1}.spm.stats.factorial_design.cov = struct('c', {}, 'cname', {}, 'iCFI', {}, 'iCC', {});
        matlabbatch{1}.spm.stats.factorial_design.multi_cov = struct('files', {}, 'iCFI', {}, 'iCC', {});
        matlabbatch{1}.spm.stats.factorial_design.masking.tm.tm_none = 1;
        matlabbatch{1}.spm.stats.factorial_design.masking.im = 1;
        matlabbatch{1}.spm.stats.factorial_design.masking.em = {''};
        matlabbatch{1}.spm.stats.factorial_design.globalc.g_omit = 1;
        matlabbatch{1}.spm.stats.factorial_design.globalm.gmsca.gmsca_no = 1;
        matlabbatch{1}.spm.stats.factorial_design.globalm.glonorm = 1;
        spm_jobman('run', matlabbatch);
        clear matlabbatch
        matlabbatch{1}.spm.stats.fmri_est.spmmat = {[output_dir6 filesep 'SPM.mat']};
        matlabbatch{1}.spm.stats.fmri_est.write_residuals = 0;
        matlabbatch{1}.spm.stats.fmri_est.method.Classical = 1;
        spm_jobman('run', matlabbatch);
        clear matlabbatch
        matlabbatch{1}.spm.stats.con.spmmat = {[output_dir6 filesep 'SPM.mat']};
        matlabbatch{1}.spm.stats.con.consess{1}.tcon.name = 'couple vs non couple';
        matlabbatch{1}.spm.stats.con.consess{1}.tcon.weights = [1 -1];
        matlabbatch{1}.spm.stats.con.consess{1}.tcon.sessrep = 'none';
        matlabbatch{1}.spm.stats.con.delete = 0;
        spm_jobman('run', matlabbatch);
    end
    
end
%% 3.1.2) Two sample t-test for paired t-test all pairs
output_dir5=[output_dir filesep 'results_allpairs_5000'];
if not(isfolder(output_dir5))
    mkdir(output_dir5);
end

nsubj=34;
ncouples=17;
contrast{1}='effect_sex_vs_neutral';
nperm=2000; % number of permutations

condition(1).name='neutral';
condition(1).folder{1}='c1_neutral';
condition(1).folder{2}='c3_neutral';
condition(1).folder{3}='c5_neutral';
condition(2).name='sex';
condition(2).folder{1}='c4_sex';
condition(3).name='positive';
condition(3).folder{1}='c6_positive';
condition(4).name='negative';
condition(4).folder{1}='c2_negative';

folder_structure{1}='reference'; %first cell is the reference
for l=1:nperm
    str=['000' num2str(l)];
    str=str(end-3:end);
    folder_structure{l+1}=['permutation_' str]; %all other cells are the permutations numbered in consequtive order
end

for k=2:2%length(condition)
    output_dir6x=[output_dir5 filesep 'paired_t-test_2000_perm_' condition(k).name '_vs_neutral'];
    output_dir6=[output_dir6x filesep contrast{1}];
    if not(isfolder(output_dir6))
        mkdir(output_dir6);
    end
    
%     str=['000' num2str(k)];
%     filename=['spmT_' str '.nii'];
    filename=['spmT_0001.nii'];
    
    %create if statement with spmT_ .nii
    
    clear files_snpm
    for l=1:length(folder_structure)
        files_snpm{l,:}=[output_dir6x filesep folder_structure{l} filesep filename];
    end
    
    
    clear matlabbatch
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.DesignName = '2 Groups: Two Sample T test; 1 scan per subject';
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.DesignFile = 'snpm_bch_ui_TwoSampT';
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.dir = {output_dir6}; %results_partner_vs_non_partner/two-way_anova/main_effect_relationship
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.scans1 = files_snpm(1,:);
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.scans2 = files_snpm(2:end,:);
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.cov = struct('c', {}, 'cname', {});
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.nPerm = 5000;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.vFWHM = [10 10 10];
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.bVolm = 1;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.ST.ST_none = 0;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.masking.tm.tm_none = 1;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.masking.im = 1;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.masking.em = {''};
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.globalc.g_omit = 1;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.globalm.gmsca.gmsca_no = 1;
    matlabbatch{1}.spm.tools.snpm.des.TwoSampT.globalm.glonorm = 1;
    matlabbatch{2}.spm.tools.snpm.cp.snpmcfg = {[output_dir6 filesep 'SnPMcfg.mat']};
    matlabbatch{3}.spm.tools.snpm.inference.SnPMmat = {[output_dir6 filesep 'SnPMcfg.mat']};
    matlabbatch{3}.spm.tools.snpm.inference.Thr.Vox.VoxSig.FWEth = 0.05;
    matlabbatch{3}.spm.tools.snpm.inference.Tsign = 1;
    matlabbatch{3}.spm.tools.snpm.inference.WriteFiltImg.WF_no = 0;
    matlabbatch{3}.spm.tools.snpm.inference.Report = 'MIPtable';
    spm_jobman('run', matlabbatch);
%     for l=1:length(folder_structure)
%         output_dir6=[output_dir6x filesep folder_structure{l}];
%         rmdir(output_dir6,'s');
%     end
end

